# if we want to build the DBUS "extra" package or not
# 0 - no DBUS support
# 1 - DBUS support
%define dbus 1

# if we want to build the Multipath-Tools "extra" package or not
# 0 - no Multipath-Tools support
# 1 - Multipath-Tools support
%define multipath 0

# if we want to build the scsi_id "extra" package or not
# 0 - do not build the package
# 1 - build it
%define scsi_id 1

# if we want to build pam_console support
# 0 - do not build the package
# 1 - build it
%define pam_console 1


Summary: A userspace implementation of devfs
Name: udev
Version: 025
Release: 1.initrd.1
License: GPL
Group: Utilities/System
Source: ftp://ftp.kernel.org/pub/linux/utils/kernel/hotplug/%{name}-%{version}.tar.gz
Source1: udev.rules
Source2: udev.permissions
Source3: udev.conf
Source4: pam_console.dev
Source5: selinux.dev
Source6: udev.sysconfig
Source7: udev.hotplug
Source8: dbus.dev
Source9: devlabel.dev

%if %{pam_console}
Source10: pam_console_setowner-1.0.tgz
%endif

Source11: ata_identify.c
Source12: ata_identify-Makefile

Source13: udev.get_persistent_device_name.sh
Source14: udev.get_unique_hardware_path.sh
Source15: udev.get_unique_drive_id.sh
Source16: udev.rules.persistent

Source20: start_udev
Source21: udev-setup-initrd

Patch1: udev-025-multipathd.patch
Patch2: udev-025-uchar.patch

ExclusiveOS: Linux
URL: http://kernel.org/pub/linux/utils/kernel/hotplug/
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
Prereq: /bin/sh fileutils hotplug
BuildRequires: dietlibc

%if %{pam_console}
BuildRequires: pam-devel
Requires: pam
%endif

%description
udev is a implementation of devfs in userspace using sysfs and
/sbin/hotplug. It requires a 2.6 kernel to run properly.

%if %{dbus}
%package -n udev-dbus
Summary: Udev to dbus interface
Group: Utilities/System
BuildRequires: dbus-devel
PreReq: dbus udev

%description -n udev-dbus
udev-dbus enables udev to send dbus messages.
%endif

%package -n udev-persistent
Summary: Persistent device naming with udev
Group: Utilities/System
PreReq: udev
Requires: sed, ash

%description -n udev-persistent
udev-persistent enables persistent device naming with udev.


%prep
%if %{pam_console}
%setup -q -a 10 
%else
%setup -q
%endif
%patch1 -p1 -b .multi
%patch2 -p1 -b .uchar
mkdir ata_identify
cp %{SOURCE11} ata_identify
cp %{SOURCE12} ata_identify/Makefile

%build
make CC="gcc $RPM_OPT_FLAGS" \
        USE_KLIBC=false \
	USE_LOG=true DEBUG=false \
	EXTRAS="	\
%if %{dbus}
	extras/dbus	\
%endif
%if %{multipath} 
	extras/multipath-tools	\
%endif
"

mv udev udev.dynamic

rm -f *.o
rm -f */*.o */*.a
%if %{multipath} 
make -C extras/multipath-tools/devmap_name clean
make -C extras/multipath-tools/multipath clean
%endif

make CC="diet gcc $RPM_OPT_FLAGS"    \
     LD="diet gcc" \
        USE_KLIBC=false \
	USE_LOG=true		\
	DEBUG=false		\
	EXTRAS="	\
%if %{scsi_id}
	extras/scsi_id	\
%endif
%if %{multipath} 
	extras/multipath-tools	\
%endif
        ata_identify"



%if %{pam_console}
pushd pam_console_setowner
make
popd
%endif


%install
rm -rf $RPM_BUILD_ROOT

mkdir -p $RPM_BUILD_ROOT%{_sbindir}

make DESTDIR=$RPM_BUILD_ROOT install \
	EXTRAS="	\
%if %{scsi_id}
	extras/scsi_id	\
%endif
%if %{dbus}
	extras/dbus	\
%endif
%if %{multipath}
	extras/multipath-tools	\
%endif
        ata_identify"


rm -f $RPM_BUILD_ROOT%{_sysconfdir}/udev/udev.rules
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/udev/udev.permissions
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/init.d/udev

mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/udev/{rules.d,permissions.d}
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/dev.d/{default,block}
install -m 0644 %{SOURCE1} $RPM_BUILD_ROOT%{_sysconfdir}/udev/rules.d/50-udev.rules
install -m 0644 %{SOURCE2} $RPM_BUILD_ROOT%{_sysconfdir}/udev/permissions.d/50-udev.permissions
install -m 0644 %{SOURCE3} $RPM_BUILD_ROOT%{_sysconfdir}/udev/udev.conf
install -m 0755 %{SOURCE4} $RPM_BUILD_ROOT%{_sysconfdir}/dev.d/default
install -m 0755 %{SOURCE5} $RPM_BUILD_ROOT%{_sysconfdir}/dev.d/default
install -m 0755 %{SOURCE8} $RPM_BUILD_ROOT%{_sysconfdir}/dev.d/default
install -m 0755 %{SOURCE9} $RPM_BUILD_ROOT%{_sysconfdir}/dev.d/block
install -m 0755 udev $RPM_BUILD_ROOT/sbin/udev.static
install -m 0755 udev.dynamic $RPM_BUILD_ROOT/sbin/udev

#persistent
install -m 0755 %{SOURCE13} $RPM_BUILD_ROOT/sbin
install -m 0755 %{SOURCE14} $RPM_BUILD_ROOT/sbin
install -m 0755 %{SOURCE15} $RPM_BUILD_ROOT/sbin
install -m 0644 %{SOURCE16} $RPM_BUILD_ROOT%{_sysconfdir}/udev/rules.d/51-udev-persistent.rules

%if %{pam_console}
install -m 0755 pam_console_setowner/pam_console_setowner $RPM_BUILD_ROOT/sbin
%endif

mkdir $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig
install -m 0644 %{SOURCE6} $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig/udev

rm -f $RPM_BUILD_ROOT%{_sysconfdir}/hotplug.d/default/udev.hotplug
install -m 0644 %{SOURCE6} $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig/udev
install -m 0755 %{SOURCE7} $RPM_BUILD_ROOT%{_sysconfdir}/hotplug.d/default/udev.hotplug


mkdir -p $RPM_BUILD_ROOT%{_datadir}/udev
install -m 0644 %{SOURCE20} $RPM_BUILD_ROOT/sbin/start_udev
install -m 0644 %{SOURCE21} $RPM_BUILD_ROOT%{_datadir}/udev/udev-setup-initrd

%if %{multipath}
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/rc.d/init.d
mv $RPM_BUILD_ROOT%{_sysconfdir}/init.d/multipathd $RPM_BUILD_ROOT%{_sysconfdir}/rc.d/init.d/multipathd
%endif


#%post
#/sbin/chkconfig --add udev

%preun
if [ $1 = 0 -a -f %{_sysconfdir}/rc.d/init.d/udev ]; then
	/sbin/chkconfig --del udev
fi

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%doc COPYING README TODO ChangeLog HOWTO*  docs/*
%doc etc/udev/udev.rules.{examples,redhat}
%doc etc/udev/udev.permissions.redhat

%attr(0755,root,root) %dir /udev

%attr(0755,root,root) /sbin/udev
%attr(0755,root,root) /sbin/udev.static
%attr(0755,root,root) /sbin/udevsend
%attr(0755,root,root) /sbin/udevd
%attr(0755,root,root) /sbin/udevstart
%attr(0755,root,root) /sbin/start_udev
%attr(755,root,root) /sbin/ata_identify

%attr(0755,root,root) %{_bindir}/udevtest
%attr(0755,root,root) %{_bindir}/udevinfo

%if %{pam_console}
%attr(0755,root,root) /sbin/pam_console_setowner
%endif

%attr(0755,root,root) %dir %{_sysconfdir}/dev.d/
%attr(0755,root,root) %dir %{_sysconfdir}/dev.d/default
%config %attr(0755,root,root) %{_sysconfdir}/dev.d/net/hotplug.dev
%config %attr(0755,root,root) %{_sysconfdir}/dev.d/default/pam_console.dev
%config %attr(0755,root,root) %{_sysconfdir}/dev.d/default/selinux.dev
%config %attr(0755,root,root) %{_sysconfdir}/dev.d/default/dbus.dev
%config %attr(0755,root,root) %{_sysconfdir}/dev.d/block/devlabel.dev
%attr(0755,root,root) %dir %{_sysconfdir}/udev/
%attr(0755,root,root) %dir %{_sysconfdir}/udev/rules.d/
%attr(0755,root,root) %dir %{_sysconfdir}/udev/permissions.d/
%config(noreplace) %attr(0644,root,root) %{_sysconfdir}/udev/udev.conf
%config %attr(0644,root,root) %{_sysconfdir}/udev/rules.d/50-udev.rules
%config %attr(0644,root,root) %{_sysconfdir}/udev/permissions.d/50-udev.permissions
%attr(0755,root,root) %{_sysconfdir}/hotplug.d/default/udev.hotplug

%config(noreplace) %attr(0644,root,root) %{_sysconfdir}/sysconfig/udev

%attr(0644,root,root) %{_mandir}/man8/udev*.8*

%attr(0644,root,root) %{_datadir}/udev/udev-setup-initrd

%if %{scsi_id}
	%attr(755,root,root) /sbin/scsi_id
	%config(noreplace) %attr(0644,root,root) %{_sysconfdir}/scsi_id.config
	%attr(0644,root,root) %{_mandir}/man8/scsi_id*.8*
%endif

%if %{multipath}
%attr(0755,root,root) %{_sysconfdir}/hotplug.d/scsi/multipath.hotplug
%attr(0755,root,root) %{_sysconfdir}/rc.d/init.d/multipathd
%attr(0755,root,root) /sbin/devmap_name
%attr(0755,root,root) /sbin/multipath
%attr(0755,root,root) %{_bindir}/multipathd
%attr(0644,root,root) %{_mandir}/man8/devmap_name.8*
%attr(0644,root,root) %{_mandir}/man8/multipath.8*
%endif

%if %{dbus}
%files -n udev-dbus
%defattr(-,root,root)
%config(noreplace) %attr(0644,root,root) %{_sysconfdir}/dbus-1/system.d/udev_sysbus_policy.conf
%attr(0755,root,root) /usr/sbin/udev_dbus
%endif


%files -n udev-persistent
%config %attr(0644,root,root) %{_sysconfdir}/udev/rules.d/51-udev-persistent.rules
%attr(0755,root,root) /sbin/udev.get_persistent_device_name.sh
%attr(0755,root,root) /sbin/udev.get_unique_hardware_path.sh
%attr(0755,root,root) /sbin/udev.get_unique_drive_id.sh

%changelog
* Wed May 26 2004 Harald Hoyer <harald@redhat.com> - 025-1
- udev-025
- added ata_identify
- build nearly all with dietlibc

* Mon May 10 2004 Elliot Lee <sopwith@redhat.com> 024-6
- Turn off udevd by default for FC2

* Tue Apr 20 2004 Harald Hoyer <harald@redhat.com> - 024-5
- fixed permission for /dev/tty (FC2)

* Thu Apr 15 2004 Harald Hoyer <harald@redhat.com> - 024-4
- moved the 00- files to 50-, to let the use place his files in front

* Thu Apr 15 2004 Harald Hoyer <harald@redhat.com> - 024-3
- set UDEV_SELINUX to yes
- added UDEV_LOG

* Thu Apr 15 2004 Harald Hoyer <harald@redhat.com> - 024-2
- added /udev to filelist

* Wed Apr 14 2004 Harald Hoyer <harald@redhat.com> - 024-1
- update to 024
- added /etc/sysconfig/udev
- added selinux, pam_console, dbus support

* Fri Mar 26 2004 Harald Hoyer <harald@redhat.com> - 023-1
- update to 023

* Wed Mar 24 2004 Bill Nottingham <notting@redhat.com> 022-1
- update to 022

* Sun Mar 21 2004 Florian La Roche <Florian.LaRoche@redhat.de>
- really move initscript

* Sun Feb 29 2004 Florian La Roche <Florian.LaRoche@redhat.de>
- move chkconv to preun
- nicer url

* Wed Feb 25 2004 Harald Hoyer <harald@redhat.com> - 018-1
- changes permissions and rules

* Mon Feb 23 2004 Dan Walsh <dwalsh@redhat.com>
- Add selinux support

* Thu Feb 19 2004 Greg Kroah-Hartman <greg@kroah.com>
- add some more files to the documentation directory
- add ability to build scsi_id and make it the default

* Mon Feb 16 2004 Greg Kroah-Hartman <greg@kroah.com>
- fix up udevd build, as it's no longer needed to be build seperatly
- add udevtest to list of files
- more Red Hat sync ups.

* Thu Feb 12 2004 Greg Kroah-Hartman <greg@kroah.com>
- add some changes from the latest Fedora udev release.

* Mon Feb 2 2004 Greg Kroah-Hartman <greg@kroah.com>
- add udevsend, and udevd to the files
- add ability to build udevd with glibc after the rest is build with klibc

* Mon Jan 26 2004 Greg Kroah-Hartman <greg@kroah.com>
- added udevinfo to rpm
- added URL to spec file
- added udevinfo's man page

* Mon Jan 05 2004 Rolf Eike Beer <eike-hotplug@sf-tec.de>
- add defines to choose the init script (Redhat or LSB)

* Tue Dec 16 2003 Robert Love <rml@ximian.com>
- install the initscript and run chkconfig on it

* Tue Nov 2 2003 Greg Kroah-Hartman <greg@kroah.com>
- changes due to config file name changes

* Fri Oct 17 2003 Robert Love <rml@tech9.net>
- Make work without a build root
- Correctly install the right files
- Pass the RPM_OPT_FLAGS to gcc so we can build per the build policy
- Put some prereqs in
- Install the hotplug symlink to udev

* Mon Jul 28 2003 Paul Mundt <lethal@linux-sh.org>
- Initial spec file for udev-0.2.
